@@ -166,6 +166,11 @@ class Pool():
         if self.xmlb_silo is None:
             return
 
+        locale = self.as_pool.get_locale()
+        locale_variants = [locale]
+        for v in GLib.get_locale_variants(locale):
+            locale_variants.append(AppStream.utils_posix_locale_to_bcp47(v))
+
         for comp_id in self.app_dict.keys():
             try:
                 comp = self.xmlb_silo.query_first(f"components/component/id[text()='{comp_id}'] /..")
@@ -175,7 +180,7 @@ class Pool():
             if self._get_verified(comp):
                 self.app_dict[comp_id].add_tag(self.remote.get_name(), "verified")
 
-            dev_name = self._get_developer(comp)
+            dev_name = self._get_developer(comp, locale_variants)
             if dev_name is not None:
                 # hack: set_project_group() is common in libappstream, so use for temporary storage
                 # to avoid another try/except for set_developer[_name]. It's going to be part of the
@@ -186,24 +191,58 @@ class Pool():
         verified = False
         try:
             verified = comp.query("custom/value[(@key='flathub::verification::verified') and (text()='true')]", 1)
-        except GLib.Error:
-            pass
+        except:
+            try:
+                verified = comp.query("metadata/value[(@key='flathub::verification::verified') and (text()='true')]", 1)
+            except:
+                pass
 
         return verified
 
-    def _get_developer(self, comp):
+    def do_query(self, node, query):
+        try:
+            return node.query(query, 1)
+        except:
+            return None
+
+    def _get_developer(self, comp, locale_variants):
         # "developer" is recent, replacing "developer_name". Currently both are allowed, though older
         # libappstream doesn't support it, causing us to only see the developer name in mintinstall if they're
         # still using "developer_name". If all else fails, project_group may have something.
+
         try:
-            developer = comp.query("developer/name", 1)[0]
-            return developer.get_text() if developer else None
-        except GLib.Error:
+            developer_node = comp.query("developer", 1)[0]
+
+            result = None
+            # locale_variants will be something like ["en_US", "en", "C"]
+            for variant in locale_variants:
+                # Look for the name with the matching locale
+                result = self.do_query(developer_node, f"name[@xml:lang='{variant}']")
+
+                if result is not None:
+                    break
+
+            if result is None:
+                # If no locales matched, there should be (??) a non-localized version as well, use that one.
+                result = self.do_query(developer_node, f"name[not(@xml:lang)]")
+
+            if result is not None:
+                return result[0].get_text()
+        except GLib.Error as e:
             pass
 
         try:
-            developer = comp.query("developer_name", 1)[0]
-            return developer.get_text() if developer else None
+            for variant in locale_variants:
+                result = self.do_query(comp, f"developer_name[@xml:lang='{variant}']")
+
+                if result is not None:
+                    break
+
+            if result is None:
+                result = self.do_query(comp, f"developer_name[not(@xml:lang)]")
+
+            if result is not None:
+                return result[0].get_text()
         except GLib.Error:
             pass
 
@@ -243,6 +282,24 @@ def _get_remote_name_by_url(fp_sys, url):
 
     return name
 
+def _should_cache_ref(ref, arch):
+    if ref.get_kind() == Flatpak.RefKind.RUNTIME:
+        return False
+
+    if ref.get_name().endswith("BaseApp"):
+        return False
+
+    if ref.get_name().endswith("BaseExtension"):
+        return False
+
+    if ref.get_arch() != arch:
+        return False
+
+    if ref.get_eol() is not None:
+        return False
+
+    return True
+
 def _process_remote(cache, rpool, fp_sys, remote, arch):
     remote_name = remote.get_name()
 
@@ -260,21 +317,8 @@ def _process_remote(cache, rpool, fp_sys, remote, arch):
 
     try:
         for ref in fp_sys.list_remote_refs_sync(remote_name, None):
-            if ref.get_kind() == Flatpak.RefKind.RUNTIME:
+            if not _should_cache_ref(ref, arch):
                 continue
-
-            if ref.get_name().endswith("BaseApp"):
-                continue
-
-            if ref.get_name().endswith("BaseExtension"):
-                continue
-
-            if ref.get_arch() != arch:
-                continue
-
-            if ref.get_eol() is not None:
-                continue
-
             _add_package_to_cache(cache, rpool, ref, remote_url, False)
     except GLib.Error as e:
         warn("Process remote:", e.message)
@@ -336,7 +380,7 @@ def process_full_flatpak_installation(cache):
                 for ref in fp_sys.list_installed_refs(None):
                     # All remotes will see installed refs, but the installed refs will always
                     # report their correct origin, so only add installed refs when they match the remote.
-                    if ref.get_origin() == remote_name:
+                    if ref.get_origin() == remote_name and _should_cache_ref(ref, arch):
                         _add_package_to_cache(cache, rpool, ref, remote.get_url(), True)
             except GLib.Error as e:
                 warn("adding packages:", e.message)
@@ -1001,6 +1045,8 @@ def generate_uncached_pkginfos(cache):
             remote_name = remote.get_name()
 
             for ref in fp_sys.list_installed_refs(None):
+                if not _should_cache_ref(ref, Flatpak.get_default_arch()):
+                    continue
                 # All remotes will see installed refs, but the installed refs will always
                 # report their correct origin, so only add installed refs when they match the remote.
                 if ref.get_origin() == remote_name:
