@@ -372,10 +372,11 @@ class FlatpakPkgInfo(PkgInfo):
             description = as_component.get_description()
 
             if description is not None:
-                description = description.replace("<p>", "").replace("</p>", "\n")
-                for tags in ["<ul>", "</ul>", "<li>", "</li>"]:
-                    description = description.replace(tags, "")
-                self.description = capitalize(description)
+                try:
+                    self.description = AppStream.markup_convert(description, AppStream.MarkupKind.TEXT)
+                except GLib.Error as e:
+                    warn("Could not convert description to text: %s" % e.message)
+                    self.description = description
 
         if self.description is None:
             return ""
